#' Integrate information needed in the detection
#'
#' @param S vector representing the true hidden states of CpG sites. 
#' States may be 'Both High', 'Both Low', 'HyperM' or 'HypoM'. 
#' Just used for random simulation, the default value is NULL.
#' @param L vector representing the distance adjacent CpG sites
#' @param site vector representing the position of each CpG sites.
#' @param nX matrix with each row  corresponds to 
#' read depth for cytosine from control group in each pair of data. 
#' @param nY matrix with each row  corresponds to 
#' read depth for cytosine from case group in each pair of data. 
#' @param X matrix with each row  corresponds to 
#' methylated counts for cytosine from control group 
#' in each pair of data.
#' @param Y matrix with each row  corresponds to
#' methylated counts for cytosine from case groups 
#' in each pair of data.
#'
#' @return Simply a list with all information are the same with input.
#' Just an integration
#' @export
#'
#' @examples
IntegrateData <- function(S = NULL,site, nX, nY, X, Y){
  N <- length(site)
  L <- diff(site)
  if(N == length(nX)){
     res <- list(S = S, pX = pX, pY = pY, L = L, site = site,
              nX = matrix(nX,N), nY = matrix(nY,N),
              X = matrix(X,N), Y = matrix(Y,N) )
  }else{
    res <- list(S = S, pX = pX, pY = pY, L = L, site = site,
                nX = matrix(nX,N), nY = matrix(nY,N),
                X = matrix(X,N), Y = matrix(Y,N) )
  }
  return(res)
 
}