
emp_all = function(data, HMM, pX, pY) {
  C <- dbinom(data$X,data$nX,pX,log=TRUE) + dbinom(data$Y,data$nY,pY,log=TRUE)  # N-by-1 matrix (data$X matrix)
  C1 <- log(sum(pnorm(c(1,0),HMM$muBH,sqrt(HMM$cBHX))*c(1,-1)))
  C2 <- log(sum(pnorm(c(1,0),HMM$muBL,sqrt(HMM$cBLX))*c(1,-1)))  
  C11 <- log( pnorm(1,pX,sqrt(HMM$cBHY))-pnorm(0,pX,sqrt(HMM$cBHY)) )
  C22 <- log( pnorm(1,pX,sqrt(HMM$cBLY))-pnorm(0,pX,sqrt(HMM$cBLY)) )
  lpX <- logit(pX); lpY = logit(pY)
  C34 <- log(pX)+log(pY)+log(1-pX)+log(1-pY)
  N <- nrow(data$X)
  return( cbind(
    rowSums(dnorm(pX,HMM$muBH,sqrt(HMM$cBHX),log=TRUE)-C1+
              dnorm(pY,pX,sqrt(HMM$cBHY),log=TRUE)-C11+C),
    rowSums(dnorm(pX,HMM$muBL,sqrt(HMM$cBLX),log=TRUE)-C2+
              dnorm(pY,pX,sqrt(HMM$cBLY),log=TRUE)-C22+C),
    rowSums(matrix(dmvnorm(cbind(c(lpX),c(lpY)),HMM$muHyper,HMM$sigmaHyper,log=TRUE),N)-C34+C),
    rowSums(matrix(dmvnorm(cbind(c(lpX),c(lpY)),HMM$muHypo,HMM$sigmaHypo,log=TRUE),N)-C34+C)))
}

rmtnorm <- function(n, mean=0, sd=1, lower=-Inf, upper=Inf) {
  u <- runif(n)
  plower <- pnorm(lower, mean, sd)
  pupper <- pnorm(upper, mean, sd)
  Fchange <- c(0,cumsum(pupper-plower)[-length(plower)])
  if(sum(pupper-plower)==0){
    bounds <- c(lower,upper)
    u <- rep(bounds[which.min(abs(bounds-mean))],n)
  }else{
    change <- cumsum(pupper-plower)/sum(pupper-plower)
    k <- mapply(function(x) which(change>x)[1],u)
    p <- plower[k] + sum(pupper - plower)*u-Fchange[k]
    u <- qnorm(p,mean,sd)
  }
  return(u)  # invert the CDFs
}

rtgamma <- function(n,lower = 0,upper =Inf,aGa,bGa){
  u <- runif(n)
  plower <- pgamma(lower, shape = aGa, scale = bGa)
  pupper <- pgamma(upper, shape = aGa, scale = bGa)
  Mean <- aGa*bGa
  if(pupper-plower == 0){
    bounds <- c(lower,upper)
    u <- rep(bounds[which.min(abs(bounds-Mean))],n)
  }else{
    p <- plower + (pupper - plower)*u
    u <- qgamma(p,shape = aGa, scale = bGa)
  }
  return(u)  # invert the CDFs
}


logit <- function(x){log(x/(1-x))}
ilogit <- function(x){ exp(x)/(1+exp(x)) }

logexpsum = function(x) { maxx = max(x); log(sum(exp(x-maxx)))+maxx }


Bound_mu1 <- function(State,mu,Sigma,alpha,D){
  
  mu1 <- mu[1]
  mu2 <- mu[2]
  s11 <- Sigma[1,1]
  s22 <- Sigma[2,2]
  s12 <- Sigma[1,2]
  # rho <- Sigma[1,2]/sqrt(s11*s22)
  
  if(State =='HyperM'){
    Cons1 <- mu2-sqrt(2*(s11+s22)*qchisq(alpha,2)-4*s12*qchisq(alpha,2))
    Cons2 <- logit(ilogit(mu2)-D) 
    return(min(Cons1,Cons2))
  }else{
    Cons1 <- mu2+sqrt(2*(s11+s22)*qchisq(alpha,2)-4*s12*qchisq(alpha,2))
    Cons2 <- logit(ilogit(mu2)+D)
    return(max(Cons1,Cons2))
  }
  
}


Bound_mu2 <- function(State,mu,Sigma,alpha,D){
  
  mu1 <- mu[1]
  mu2 <- mu[2]
  s11 <- Sigma[1,1]
  s22 <- Sigma[2,2]
  s12 <- Sigma[1,2]
  # rho <- Sigma[1,2]/sqrt(s11*s22)
  
  if(State =='HyperM'){
    Cons1 <- mu1+sqrt(2*(s11+s22)*qchisq(alpha,2)-4*s12*qchisq(alpha,2))
    Cons2 <- logit(ilogit(mu1)+D) 
    return(max(Cons1,Cons2))
  }else{
    Cons1 <- mu1-sqrt(2*(s11+s22)*qchisq(alpha,2)-4*s12*qchisq(alpha,2))
    Cons2 <- logit(ilogit(mu1)-D)
    return(min(Cons1,Cons2))
  }
  
}



Bound_rho <- function(mu,Sigma,alpha){
  mu1 <- mu[1]
  mu2 <- mu[2]
  s11 <- Sigma[1,1]
  s22 <- Sigma[2,2]
  R12L <- -((mu1-mu2)^2-2*(s11+s22)*qchisq(alpha,2))/(4*sqrt(s11*s22)*qchisq(alpha,2))
  return(max(R12L,-1))
}

Bound_sigma1 <- function(mu,Sigma,alpha){
  mu1 <- mu[1]
  mu2 <- mu[2]
  s11 <- Sigma[1,1]
  s22 <- Sigma[2,2]
  rho <- Sigma[1,2]/sqrt(s11*s22)
  da <- 2*qchisq(alpha,2)
  db <- -4*rho*sqrt(s22)*qchisq(alpha,2)
  dc <- -(mu1-mu2)^2+2*s22*qchisq(alpha,2)
  Delta <- db^2-4*da*dc
  if( Delta > 0){
    # Range <- as.numeric(polyroot(c(dc,db,da)))
    # return(sort(Range))
    RL <- (-db-sqrt(Delta))/(2*da)
    RU <- (-db+sqrt(Delta))/(2*da)
    if(RU>0){
      if(RL<0){
        return(c(0,RU)) 
      }else{
        return(c(RL,RU))
      }
    }else{
      stop('RU<0')
    }
    
  }else{
    stop('Delta<0')
    
  }
}

Bound_sigma2 <- function(mu,Sigma,alpha){
  mu1 <- mu[1]
  mu2 <- mu[2]
  s11 <- Sigma[1,1]
  s22 <- Sigma[2,2]
  rho <- Sigma[1,2]/sqrt(s11*s22)
  da <- 2*qchisq(alpha,2)
  db <- -4*rho*sqrt(s11)*qchisq(alpha,2)
  dc <- 2*s11*qchisq(alpha,2)-(mu1-mu2)^2
  Delta <- db^2-4*da*dc
  if(Delta > 0){
    # Range <- as.numeric(polyroot(c(dc,db,da)))
    # return(sort(Range))
    RL <- (-db-sqrt(Delta))/(2*da)
    RU <- (-db+sqrt(Delta))/(2*da)
    if(RU>0){
      if(RL<0){
        return(c(0,RU)) 
      }else{
        return(c(RL,RU))
      }
    }else{
      stop('RU<0')
    }
    
  }else{
    stop('Delta<0')
  }
}



