#' The forwar-backward Gibbs sampler to sample the hidden states.
#'
#' @param HMM list of the informations of the HMM including states,
#' startprob and the mean and variance at each states.
#' @param emp 4-by-N matrix of log prob of observation and underlying prob for the i-th CpG site, 
#' given the state and parameters of the model:
#' @param bw 4-by-N matrix of log prob of observation and underlying prob after the i-th CpG site, 
#' given the state and parameters of the model:
#' @param L vector of the distance between neighboouring sites
#' @param ending vector of ending positions of each chains
#'
#' @return  list contains:
#' \item{States}{Length-T vector of hidden states}
#' \item{PostProb}{Length-T vector representing the 
#' logarithm of the joint probabilities of state,observation and underlying probability}
#' @export
#'
#' @examples
SampleStates <- function(HMM,emp,bw,L,ending = NULL){
  if (is.null(ending)) {
    ending <- which((L > 100000) | L < 0)
  }
  starting <- c(1,ending[-length(ending)]+1)
  
  bw = backwardc(HMM,t(emp),L,starting,ending)
  dimnames(bw) = list(states=HMM$States,index=1:T)
  states.i = SampleStatesc(HMM,emp,bw,L,starting,ending)
  probObs = postprobc(tempHMM,t(emp),data$L,states.i,starting,ending)
  states = HMM$States[states.i]
  return(list(States=states,PostProb=probObs))
}