#' Title  
#'
#' @param site    CpG site in the  rawdata
#' @param p.state Estimated hidden states
#' @param State   'HyperM' or 'HypoM'
#' @param index   
#' @param N       Number of CpG sites
#' @param pN      proportions of methylated counts of Normal cell
#' @param pT      proportions of methylated counts of Tumor cell
#'
#' @return        A picture containing difference of proportions of methylated counts and 
#' the estimated DMRs
#' @export
#'
#' @examples
plot_DMRcheck <- function(site,p.state,State,index,N,pN,pT){
  cratio <- 0.8
  par(mar=c(2, 4, 2, 6) + 0.1)
  if(State == 'HyperM'){
    DMRrow <- which(p.state == 3)
  }else{
    DMRrow <- which(p.state==4)
  }
  lDMR <- DMRrow[-1]-DMRrow[-length(DMRrow)]
  newDMR <- c(DMRrow[1],DMRrow[which(lDMR>1)+1])
  newDMR_end <- DMRrow[which(lDMR>1)]
  rplot <- max(newDMR[index]-5,0):min(newDMR_end[index]+5,N)
  sii <- site[rplot]
  ccc = rep(0,N)
  ccc[p.state==1] = 2
  ccc[p.state==2] = 3
  ccc[p.state==3] = 4
  ccc[p.state==4] = 5
  

  plot(sii,pN[rplot], pch=16, axes=FALSE, ylim=c(0,1), xlab="", ylab="", 
       type="p",col=ccc[rplot])
  axis(2, ylim=c(0,1),col="black",las=1,cex.axis=cratio)  ## las=1 makes horizontal labels
  mtext("pN, pT",side=2,line=2.5,cex=cratio)
  points(sii,pT[rplot], pch=17,col=ccc[rplot])
  abline(v=(site[newDMR[index]-1]+site[newDMR[index]])/2)
  abline(v=(site[newDMR_end[index]]+site[newDMR_end[index]+1])/2)
  box()
  
  ## Allow a second plot on the same graph
  par(new=TRUE)
  
  ## Plot the second plot and put axis scale on right
  plot(sii,pT[rplot]-pN[rplot],xlab="", ylab="", ylim=c(-.5,.5), 
       axes=FALSE, type="h", col=ccc[rplot])
  mtext("pT-pN",side=4,line=2,cex=cratio) 
  axis(4, ylim=c(-.5,.5),las=1,cex.axis=cratio)
  abline(h=0)
  
  ## Draw the time axis
  axis(1,pretty(range(sii),10),cex.axis=cratio)
  
}

