% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Sampler.R
\name{Sampler}
\alias{Sampler}
\title{Gibbs Sampler to estimate model parameters}
\usage{
Sampler(data, e0 = rep(5, 4), mu01 = 0.7, mu02 = 0.3, sigma01 = 1,
  sigma02 = 1, mu03 = c(-0.3, 0.7), mu04 = c(0.7, -0.3),
  sigma03 = diag(2), sigma04 = diag(2), vx012 = 2, Sx012 = 0.1,
  vy012 = 2, Sy012 = 0.01, ending = NULL, init, burnin = 8000,
  iter = 10000, seed = 912, alpha = 0.8, ads = rep(0.1, 2),
  sstemp = rep(0.05, 2), adspXi = 0.5, adspYi = 0.5,
  sshapeBH = c(20, 20), sshapeBL = c(10, 10), shape11 = c(10, 10),
  shape22 = c(10, 10), adjpar = c(0.9, 1.1), D = 0.3, filename,
  adjust = TRUE, nadjust = 2000)
}
\arguments{
\item{data}{Integrated data, including all the information from WGBS data used in sampler.}

\item{e0}{length-4 vector representing the means of priors of \eqn{e_k}. The default value is (5,5,5,5).}

\item{mu01}{expectation of \eqn{mu_{X1}}'s  prior. 
Default is 0.7.}

\item{mu02}{expectation of \eqn{mu_{X2}}'s prior. Default is 0.3}

\item{sigma01}{standard deviation of \eqn{mu_{X1}}'s prior. Default is 1.}

\item{sigma02}{standard deviation of \eqn{mu_{X2}}'s prior. Default is 1.}

\item{mu03}{vector of means of \eqn{mu_3}'s prior. Default is \eqn{(-0.3,0.7)}.}

\item{mu04}{vector of means of \eqn{mu_4}'s prior. Default is \eqn{(0.7,-0.3)}}

\item{sigma03}{Covariance matrix of \eqn{mu_3}'s prior. Default is \eqn{diag(2)}}

\item{sigma04}{Covariance matrix of \eqn{mu_4}'s prior. Default is \eqn{diag(2)}}

\item{vx012}{shape parameter of \eqn{sigma_{Xk}}'s prior, k=1,2. Default is 2.}

\item{Sx012}{scale parameter of \eqn{sigma_{Xk}}'s prior, k=1,2. Default is 0.1.}

\item{vy012}{shape parameter of \eqn{sigma_{Yk}}'s prior, k=1,2. Default is 2.}

\item{Sy012}{scale parameter of \eqn{sigma_{Yk}}'s prior, k=1,2. Default is 0.01}

\item{ending}{ending of each chain. Default is NULL, 
and a new chain will be initialized when
distance larger than 10,000bp.}

\item{init}{list of initial values}

\item{burnin}{number of iterations for burn-in (including parameter adjustment). Default is 8000.}

\item{iter}{total number of iterations. Defaut is 10000}

\item{seed}{a single value, interpreted as an integer. Default is 912.}

\item{alpha}{tunning parameter in model, 
which used to truncating the covariant matrices of bivariate normals of DMC's responses. 
Default is 0.8}

\item{ads}{standard deviation of \eqn{mu_{Xk}}'s proposal,\eqn{k=1,2}}

\item{sstemp}{standard deviation of \eqn{rho_{Xk}}'s proposal, \eqn{k=3,4}. default is \eqn{(0.05,0.05)}}

\item{adspXi}{standard deviation of \eqn{p_{X}}'s proposal. default is 0.5}

\item{adspYi}{standard deviation of \eqn{p_{Y}}'s proposal. default is 0.5}

\item{sshapeBH}{length-2 vector representing the shape parameter 
of \eqn{sigma_{X1}} and \eqn{sigma_{Y1}}'s proposal. Defaut is \eqn{(20,20)}.}

\item{sshapeBL}{length-2 vector representing theshape parameter 
of \eqn{sigma_{X2}} and \eqn{sigma_{Y2}}'s proposal. Defaut is \eqn{(10,10)}.}

\item{shape11}{length-2 vector representing the shape parameter 
of \eqn{sigma_{13}} and \eqn{sigma_{14}}'s proposal. Defaut is \eqn{(10,10)}.}

\item{shape22}{length-2 vector representing the shape parameter 
of \eqn{sigma_{23}} and \eqn{sigma_{24}}'s proposal. Defaut is \eqn{(10,10)}.}

\item{adjpar}{length-2 vector used to adjust parameters in proposals, 
the first element smaller 1 and the last element bigger than 1.
Default is \eqn{(0.9,1.1)}}

\item{D}{tunning parameter in model, 
which represent the minimun difference between the mean of \eqn{pX_{ij}} and \eqn{pY_{ij}} in the DMR regions.
Default is 0.3}

\item{filename}{output file name}

\item{adjust}{logical; if TRUE(default), adjust parameters in proposal automatically.}

\item{nadjust}{number of iterations for parameter adjustment. Only works when adjust = TRUE. Default is 2000.}
}
\description{
Given the paired WGBS data, this function calls Sampler for 
estimationg the parameters of non-homogeneous hidden Markov model.
}
